# NSKBot - Selenium Automation Bot

NSKBot là một bộ công cụ tự động hóa (RPA) được phát triển để hỗ trợ các quy trình làm việc của NSK.

## Yêu cầu Hệ thống

- Python 3.12+
- Các thư viện cần thiết được quản lý trong `pyproject.toml`

## Các chức năng hỗ trợ hiện tại

- [x] SharePoint 365

  - [x] Tải **File** theo **URL**

- [x] Web Access

  - [x] Cập nhật thông tin đơn hàng
  - [x] Lấy thông tin đơn hàng

- [x] Mail Dealer

  - [x] Gửi **Email**
